@@ -23,6 +23,8 @@ import random
 
 class glob(object):
 
+    circle_sprite = None
+    circle_pop_sprite = None
     font = None
     pop_sound = None
     music = None
@@ -58,7 +60,7 @@ class Game(sge.Game):
 class Circle(sge.Object):
 
     def __init__(self, x, y):
-        super(Circle, self).__init__(x, y, 5, sprite='circle',
+        super(Circle, self).__init__(x, y, 5, sprite=glob.circle_sprite,
                                      collision_precise=True)
 
     def event_create(self):
@@ -90,7 +92,7 @@ class Circle(sge.Object):
 class CirclePop(sge.Object):
 
     def __init__(self, x, y):
-        super(CirclePop, self).__init__(x, y, 5, sprite='circle_pop',
+        super(CirclePop, self).__init__(x, y, 5, sprite=glob.circle_pop_sprite,
                                         tangible=False)
 
     def event_animation_end(self):
@@ -127,6 +129,9 @@ class Room(sge.Room):
         self.project_dot(90, 34, 3, sge.Color("maroon"))
         self.project_dot(91, 34, 3, sge.Color("maroon"))
         self.project_dot(90, 35, 3, sge.Color("maroon"))
+        self.project_polygon([(128, 128), (124, 160), (160, 140)], 3,
+                             fill=sge.Color("gray"), outline=sge.Color("red"),
+                             outline_thickness=3)
         text = "I am amazing text!\n\nYaaaaaaaaaaay~!"
         self.project_text(glob.font, text, 320, 0, 3, color=sge.Color("black"),
                           halign=sge.ALIGN_CENTER)
@@ -146,18 +151,18 @@ class Room(sge.Room):
             self.views[0].yport += random.uniform(-2, 2)
             self.shake -= 1
             if self.shake > 0:
-                self.set_alarm("shake", 1)
+                self.alarms["shake"] = 1
             else:
                 self.views[0].xport = 0
                 self.views[0].yport = 0
         elif alarm_id == "shake_down":
             self.views[0].yport = 3
-            self.set_alarm("shake_up", 1)
+            self.alarms["shake_up"] = 1
         elif alarm_id == "shake_up":
             self.views[0].yport = 0
             self.shake -= 1
             if self.shake > 0:
-                self.set_alarm("shake_down", 1)
+                self.alarms["shake_down"] = 1
 
     def event_key_press(self, key, char):
         if key in ("ctrl_left", "ctrl_right"):
@@ -173,10 +178,10 @@ def main():
     game = Game(delta=True, collision_events_enabled=False)
 
     # Load sprites
-    circle_sprite = sge.Sprite('circle', width=64, height=64, origin_x=32,
-                               origin_y=32)
-    circle_pop_sprite = sge.Sprite('circle_pop', width=64, height=64,
-                                   origin_x=32, origin_y=32, fps=60)
+    glob.circle_sprite = sge.Sprite('circle', width=64, height=64, origin_x=32,
+                                    origin_y=32)
+    glob.circle_pop_sprite = sge.Sprite('circle_pop', width=64, height=64,
+                                        origin_x=32, origin_y=32, fps=60)
     fence_sprite = sge.Sprite('fence')
 
     # Load backgrounds
@@ -203,7 +208,7 @@ def main():
     views = [sge.View(0, 0)]
 
     # Create rooms
-    room1 = Room(objects, views=views, background=background)
+    game.start_room = Room(objects, views=views, background=background)
 
     game.start()
 
