@@ -23,9 +23,10 @@ from __future__ import unicode_literals
 import os
 
 import pygame
+import six
 
 import sge
-from sge import six
+from sge.r import f_split_text, s_get_image
 
 
 __all__ = ['Font']
@@ -33,10 +34,8 @@ __all__ = ['Font']
 
 class Font(object):
 
-    """Font handling class.
-
-    This class stores a font for use by :meth:`sge.Sprite.draw_text` and
-    :meth:`sge.Room.project_text`.
+    """
+    This class stores a font for use by text drawing methods.
 
     Note that bold and italic rendering could be ugly.  It is better to
     choose a bold or italic font rather than enabling bold or italic
@@ -74,19 +73,18 @@ class Font(object):
        The name of the font as specified when it was created.
        (Read-only)
 
-    .. attribute:: id
-
-       The unique identifier of the font.  (Read-only)
+    .. attribute:: rd
 
+       Reserved dictionary for internal use by the SGE.  (Read-only)
     """
 
     @property
     def size(self):
-        return self._size
+        return self.__size
 
     @size.setter
     def size(self, value):
-        if self._font is not None:
+        if self.rd.get("font") is not None:
             # Preserve underline, bold, and italic settings.
             underline = self.underline
             bold = self.bold
@@ -96,8 +94,8 @@ class Font(object):
             bold = False
             italic = False
 
-        self._size = value
-        self._font = None
+        self.__size = value
+        self.rd["font"] = None
 
         name = self.name
         if isinstance(name, six.string_types):
@@ -134,14 +132,14 @@ class Font(object):
             for name in names:
                 path = os.path.join(path, name)
                 if os.path.isfile(path):
-                    self._font = pygame.font.Font(path, self._size)
+                    self.rd["font"] = pygame.font.Font(path, self.__size)
                     break
 
-            if self._font is not None:
+            if self.rd.setdefault("font") is not None:
                 break
 
-        if self._font is None:
-            self._font = pygame.font.SysFont(','.join(names), self._size)
+        if self.rd.get("font") is None:
+            self.rd["font"] = pygame.font.SysFont(','.join(names), self.__size)
 
         # Restore underline, bold, and italic settings.
         self.underline = underline
@@ -150,32 +148,31 @@ class Font(object):
 
     @property
     def underline(self):
-        return self._font.get_underline()
+        return self.rd["font"].get_underline()
 
     @underline.setter
     def underline(self, value):
-        self._font.set_underline(bool(value))
+        self.rd["font"].set_underline(bool(value))
 
     @property
     def bold(self):
-        return self._font.get_bold()
+        return self.rd["font"].get_bold()
 
     @bold.setter
     def bold(self, value):
-        self._font.set_bold(bool(value))
+        self.rd["font"].set_bold(bool(value))
 
     @property
     def italic(self):
-        return self._font.get_italic()
+        return self.rd["font"].get_italic()
 
     @italic.setter
     def italic(self, value):
-        self._font.set_italic(bool(value))
-
-    def __init__(self, name=None, ID=None, size=12, underline=False,
-                 bold=False, italic=False):
-        """Constructor method.
+        self.rd["font"].set_italic(bool(value))
 
+    def __init__(self, name=None, size=12, underline=False, bold=False,
+                 italic=False):
+        """
         Arguments:
 
         - ``name`` -- The name of the font.  Can be one of the
@@ -192,10 +189,6 @@ class Font(object):
           If none of the above methods return a valid font, the SGE will
           choose the font.
 
-        - ``ID`` -- The value to set :attr:`id` to.  If set to
-          :const:`None`, ``name`` will be used, modified by the SGE if
-          it is already the unique identifier of another font.
-
         All other arguments set the respective initial attributes of the
         font.  See the documentation for :class:`sge.Font` for more
         information.
@@ -213,38 +206,26 @@ class Font(object):
            the GNU General Public License or the SIL Open Font License)
            and distribute it with your game; this will ensure that
            everyone sees text rendered the same way you do.
-
         """
+        self.rd = {}
         self.name = name
-        self._font = None
         self.size = size
         self.underline = underline
         self.bold = bold
         self.italic = italic
 
-        fonts = sge.game.fonts.copy()
-        if ID is not None:
-            self.id = ID
-        else:
-            self.id = str(self.name)
-
-            while self.id in fonts:
-                self.id += "_"
-
-        fonts[self.id] = self
-        sge.game.fonts = fonts
-
     def get_width(self, text, width=None, height=None):
-        """Return the width of a certain string of text when rendered.
+        """
+        Return the width of a certain string of text when rendered.
 
         See the documentation for :meth:`sge.Sprite.draw_text` for
-        information about the arguments.
+        more information.
 
         """
-        lines = self._split_text(text, width)
+        lines = f_split_text(self, text, width)
         text_width = 0
         for line in lines:
-            text_width = max(text_width, self._font.size(line)[0])
+            text_width = max(text_width, self.rd["font"].size(line)[0])
 
         if width is not None:
             text_width = min(text_width, width)
@@ -252,16 +233,17 @@ class Font(object):
         return text_width
 
     def get_height(self, text, width=None, height=None):
-        """Return the height of a certain string of text when rendered.
+        """
+        Return the height of a certain string of text when rendered.
 
         See the documentation for :meth:`sge.Sprite.draw_text` for
-        information about the arguments.
+        more information.
 
         """
-        lines = self._split_text(text, width)
+        lines = f_split_text(self, text, width)
         if lines:
-            text_height = self._font.get_linesize() * (len(lines) - 1)
-            text_height += self._font.size(lines[-1])[1]
+            text_height = self.rd["font"].get_linesize() * (len(lines) - 1)
+            text_height += self.rd["font"].size(lines[-1])[1]
         else:
             text_height = 0
 
@@ -270,17 +252,11 @@ class Font(object):
 
         return text_height
 
-    def destroy(self):
-        """Destroy the font."""
-        fonts = sge.game.fonts.copy()
-        if self.id in fonts:
-            del fonts[self.id]
-            sge.game.fonts = fonts
-
     @classmethod
-    def from_sprite(cls, sprite, chars, ID=None, hsep=0, vsep=0, size=12,
+    def from_sprite(cls, sprite, chars, hsep=0, vsep=0, size=12,
                     underline=False, bold=False, italic=False):
-        """Return a font derived from a sprite.
+        """
+        Return a font derived from a sprite.
 
         Arguments:
 
@@ -293,10 +269,6 @@ class Font(object):
           listed here will be rendered as its differently-cased
           counterpart if possible (e.g. "A" as "a") or as a blank space
           otherwise.
-        - ``ID`` -- The value to set :attr:`id` to.  If set to
-          :const:`None`, the name of the sprite will be used, modified
-          by the SGE if it is already the unique identifier of another
-          font.
         - ``hsep`` -- The amount of horizontal space to place between
           characters when text is rendered.
         - ``vsep`` -- The amount of vertical space to place between
@@ -312,34 +284,9 @@ class Font(object):
         The font's :attr:`size` attribute will indicate the height of
         the characters in pixels.  The width of the characters will be
         adjusted proportionally.
-
         """
-        return _SpriteFont(sprite, chars, ID, hsep, vsep, size, underline,
-                           bold, italic)
-
-    def _split_text(self, text, width=None):
-        # Split the text into lines of the proper size for ``width`` and
-        # return a list of the lines.  If ``width`` is None, only
-        # newlines split the text.
-        lines = text.splitlines()
-
-        if width is None:
-            return lines
-        else:
-            split_text = []
-            for line in lines:
-                if self._font.size(line)[0] <= width:
-                    split_text.append(line)
-                else:
-                    words = line.split(' ')
-                    while words:
-                        current_line = words.pop(0)
-                        while (words and self._font.size(' '.join(
-                                [current_line, words[0]]))[0] <= width):
-                            current_line = ' '.join([current_line,
-                                                     words.pop(0)])
-                        split_text.append(current_line)
-            return split_text
+        return _SpriteFont(sprite, chars, hsep, vsep, size, underline, bold,
+                           italic)
 
 
 class _PygameSpriteFont(pygame.font.Font):
@@ -393,14 +340,14 @@ class _PygameSpriteFont(pygame.font.Font):
 
         for i in six.moves.range(len(text)):
             if text[i] in self.chars:
-                cimg = self.sprite._get_image(self.chars[text[i]],
-                                              xscale=xscale,
-                                              yscale=yscale, blend=sge_color)
+                cimg = s_get_image(self.sprite, self.chars[text[i]],
+                                   xscale=xscale, yscale=yscale,
+                                   blend=sge_color)
                 surf.blit(cimg, (i * (self.width + self.hsep), 0))
             elif text[i].swapcase() in self.chars:
-                cimg = self.sprite._get_image(self.chars[text[i].swapcase()],
-                                              xscale=xscale,
-                                              yscale=yscale, blend=sge_color)
+                cimg = s_get_image(self.sprite, self.chars[text[i].swapcase()],
+                                   xscale=xscale, yscale=yscale,
+                                   blend=sge_color)
                 surf.blit(cimg, (i * (self.width + self.hsep), 0))
 
         if background is None:
@@ -455,31 +402,17 @@ class _SpriteFont(Font):
 
     @property
     def size(self):
-        return self._font.vsize
+        return self.rd["font"].vsize
 
     @size.setter
     def size(self, value):
-        self._font.vsize = value
-
-    def __init__(self, sprite, chars, ID=None, hsep=0, vsep=0, size=12,
-                 underline=False, bold=False, italic=False):
-        if not isinstance(sprite, sge.Sprite):
-            sprite = sge.game.sprites[sprite]
+        self.rd["font"].vsize = value
 
+    def __init__(self, sprite, chars, hsep=0, vsep=0, size=12, underline=False,
+                 bold=False, italic=False):
+        self.rd = {}
         self.name = sprite.name
-        self._font = _PygameSpriteFont(sprite, chars, hsep, vsep, size)
+        self.rd["font"] = _PygameSpriteFont(sprite, chars, hsep, vsep, size)
         self.underline = underline
         self.bold = bold
         self.italic = italic
-
-        fonts = sge.game.fonts.copy()
-        if ID is not None:
-            self.id = ID
-        else:
-            self.id = self.name
-
-            while self.id in fonts:
-                self.id += "_"
-
-        fonts[self.id] = self
-        sge.game.fonts = fonts
