@@ -25,6 +25,7 @@ import os
 import pygame
 
 import sge
+from sge import r
 
 
 __all__ = ['Music']
@@ -32,8 +33,7 @@ __all__ = ['Music']
 
 class Music(object):
 
-    """Music handling class.
-
+    """
     This class stores and plays music.  Music is very similar to sound
     effects, but only one music file can be played at a time, and it is
     more efficient for larger files than :class:`sge.Sound`.
@@ -61,10 +61,6 @@ class Music(object):
        The file name of the music given when it was created.
        (Read-only)
 
-    .. attribute:: id
-
-       The unique identifier of the music.  (Read-only)
-
     .. attribute:: length
 
        The length of the music in milliseconds.  (Read-only)
@@ -78,37 +74,46 @@ class Music(object):
        The current position (time) playback of the music is at in
        milliseconds.  (Read-only)
 
+    .. attribute:: rd
+
+       Reserved dictionary for internal use by the SGE.  (Read-only)
     """
 
     @property
     def volume(self):
-        return self._volume
+        return self.__volume
 
     @volume.setter
     def volume(self, value):
-        self._volume = min(value, 100)
+        self.__volume = min(value, 100)
 
         if self.playing:
             pygame.mixer.music.set_volume(value / 100)
 
     @property
     def length(self):
-        return self._length
+        if self.__length is None:
+            if self.__full_fname is not None:
+                snd = pygame.mixer.Sound(self.__full_fname)
+                self.__length = snd.get_length() * 1000
+            else:
+                self.__length = 0
+
+        return self.__length
 
     @property
     def playing(self):
-        return sge.game._music is self and pygame.mixer.music.get_busy()
+        return r.music is self and pygame.mixer.music.get_busy()
 
     @property
     def position(self):
         if self.playing:
-            return self._start + pygame.mixer.music.get_pos()
+            return self.__start + pygame.mixer.music.get_pos()
         else:
             return 0
 
-    def __init__(self, fname, ID=None, volume=100):
-        """Constructor method.
-
+    def __init__(self, fname, volume=100):
+        """
         Arguments:
 
         - ``fname`` -- The name of the sound file in one of the paths
@@ -116,62 +121,39 @@ class Music(object):
           :const:`None`, this object will not actually play any music.
           If this is neither a valid sound file nor :const:`None`,
           :exc:`IOError` is raised.
-        - ``ID`` -- The value to set :attr:`id` to.  If set to
-          :const:`None`, ``fname`` minus the extension will be used,
-          modified by the SGE if it is already the unique idenfifier of
-          another music object.
 
         All other arguments set the respective initial attributes of the
         music.  See the documentation for :class:`sge.Music` for more
         information.
-
         """
-        music = sge.game.music.copy()
-
+        self.rd = {}
         self.fname = fname
         self.volume = volume
-        self._timeout = None
-        self._fade_time = None
-        self._start = 0
+        self.rd["timeout"] = None
+        self.rd["fade_time"] = None
+        self.__start = 0
+        self.__length = None
 
         if self.fname is not None and pygame.mixer.get_init():
-            self._full_fname = None
+            self.__full_fname = None
             for path in sge.music_directories:
                 path = os.path.join(path, fname)
                 if os.path.isfile(path):
-                    self._full_fname = path
+                    self.__full_fname = path
                     break
 
-            if self._full_fname is None:
+            if self.__full_fname is None:
                 print("Directories searched:")
                 for d in sge.music_directories:
                     print(os.path.normpath(os.path.abspath(d)))
                 msg = 'File "{}" not found.'.format(self.fname)
                 raise IOError(msg)
-
-            if ID is not None:
-                self.id = ID
-            else:
-                self.id = os.path.splitext(os.path.basename(self.fname))[0]
-                while self.id in music:
-                    self.id += "_"
         else:
-            self._full_fname = None
-
-            if ID is not None:
-                self.id = ID
-            else:
-                i = 0
-                while i in music:
-                    i += 1
-
-                self.id = i
-
-        music[self.id] = self
-        sge.game.music = music
+            self.__full_fname = None
 
     def play(self, start=0, loops=1, maxtime=None, fade_time=None):
-        """Play the music.
+        """
+        Play the music.
 
         Arguments:
 
@@ -180,20 +162,19 @@ class Music(object):
 
         See the documentation for :meth:`sge.Sound.play` for more
         information.
-
         """
-        if self._full_fname is not None:
+        if self.__full_fname is not None:
             if not self.playing:
-                pygame.mixer.music.load(self._full_fname)
+                pygame.mixer.music.load(self.__full_fname)
 
             if not loops:
                 loops = -1
 
-            sge.game._music = self
-            self._timeout = maxtime
-            self._fade_time = fade_time
+            r.music = self
+            self.rd["timeout"] = maxtime
+            self.rd["fade_time"] = fade_time
 
-            if self._fade_time is not None and self._fade_time > 0:
+            if fade_time is not None and fade_time > 0:
                 pygame.mixer.music.set_volume(0)
             else:
                 pygame.mixer.music.set_volume(self.volume / 100)
@@ -205,41 +186,31 @@ class Music(object):
                 self._start = 0
                 pygame.mixer.music.play(loops, start)
             else:
-                self._start = start
+                self.__start = start
                 try:
                     pygame.mixer.music.play(loops, start / 1000)
                 except NotImplementedError:
                     pygame.mixer.music.play(loops)
 
     def queue(self, start=0, loops=1, maxtime=None, fade_time=None):
-        """Queue the music for playback.
+        """
+        Queue the music for playback.
 
         This will cause the music to be added to a list of music to play
         in order, after the previous music has finished playing.
 
         See the documentation for :meth:`sge.Music.play` for more
         information.
-
         """
-        sge.game._music_queue.append((self, start, loops, maxtime, fade_time))
-
-    def destroy(self):
-        """Destroy the music."""
-        if self.playing:
-            self.stop()
-
-        music = sge.game.music.copy()
-        if self.id in music:
-            del music[self.id]
-        sge.game.music = music
+        r.music_queue.append((self, start, loops, maxtime, fade_time))
 
     @staticmethod
     def stop(fade_time=None):
-        """Stop the currently playing music.
+        """
+        Stop the currently playing music.
 
         See the documentation for :meth:`sge.Sound.stop` for more
         information.
-
         """
         if fade_time:
             pygame.mixer.music.fadeout(fade_time)
@@ -259,4 +230,4 @@ class Music(object):
     @staticmethod
     def clear_queue():
         """Clear the music queue."""
-        sge.game._music_queue = []
+        r.music_queue = []
