@@ -24,8 +24,12 @@ import os
 import warnings
 
 import pygame
+import six
 
 import sge
+from sge import r
+from sge.r import (_get_blend_flags, f_split_text, s_set_size, s_refresh,
+                   s_set_transparency)
 
 
 __all__ = ['Sprite']
@@ -33,8 +37,7 @@ __all__ = ['Sprite']
 
 class Sprite(object):
 
-    """Class which holds information for images and animations.
-
+    """
     This class stores images and information about how the SGE is to use
     those images.
 
@@ -121,47 +124,46 @@ class Sprite(object):
 
        The name of the sprite given when it was created.  (Read-only)
 
-    .. attribute:: id
-
-       The unique identifier of the sprite.  (Read-only)
-
     .. attribute:: frames
 
        The number of animation frames in the sprite.  (Read-only)
 
+    .. attribute:: rd
+
+       Reserved dictionary for internal use by the SGE.  (Read-only)
     """
 
     @property
     def width(self):
-        return int(round(self._w))
+        return self.__w
 
     @width.setter
     def width(self, value):
-        if self._w != value:
-            self._w = value
-            self._set_size()
-            self._refresh()
+        if self.__w != value:
+            self.__w = int(round(value))
+            s_set_size(self)
+            s_refresh(self)
 
     @property
     def height(self):
-        return int(round(self._h))
+        return self.__h
 
     @height.setter
     def height(self, value):
-        if self._h != value:
-            self._h = value
-            self._set_size()
-            self._refresh()
+        if self.__h != value:
+            self.__h = int(round(value))
+            s_set_size(self)
+            s_refresh(self)
 
     @property
     def transparent(self):
-        return self._transparent
+        return self.__transparent
 
     @transparent.setter
     def transparent(self, value):
-        if self._transparent != value:
-            self._transparent = value
-            self._refresh()
+        if self.__transparent != value:
+            self.__transparent = value
+            s_refresh(self)
 
     @property
     def speed(self):
@@ -173,36 +175,34 @@ class Sprite(object):
 
     @property
     def bbox_x(self):
-        return self._bbox_x
+        return self.__bbox_x
 
     @bbox_x.setter
     def bbox_x(self, value):
         if value is not None:
-            self._bbox_x = value
+            self.__bbox_x = value
         else:
-            self._bbox_x = -self.origin_x
+            self.__bbox_x = -self.origin_x
 
     @property
     def bbox_y(self):
-        return self._bbox_y
+        return self.__bbox_y
 
     @bbox_y.setter
     def bbox_y(self, value):
         if value is not None:
-            self._bbox_y = value
+            self.__bbox_y = value
         else:
-            self._bbox_y = -self.origin_y
+            self.__bbox_y = -self.origin_y
 
     @property
     def frames(self):
-        return len(self._baseimages)
-
-    def __init__(self, name=None, ID=None, width=None, height=None,
-                 transparent=True, origin_x=0, origin_y=0, fps=60,
-                 bbox_x=None, bbox_y=None, bbox_width=None,
-                 bbox_height=None):
-        """Constructor method.
+        return len(self.rd["baseimages"])
 
+    def __init__(self, name=None, width=None, height=None, transparent=True,
+                 origin_x=0, origin_y=0, fps=60, bbox_x=None, bbox_y=None,
+                 bbox_width=None, bbox_height=None):
+        """
         Arguments:
 
         - ``name`` -- The base name of the image files, used to find all
@@ -232,38 +232,23 @@ class Sprite(object):
           If none of the above rules can be used, :exc:`IOError` is
           raised.
 
-        - ``ID`` -- The value to assign :attr:`id` to.  If set to
-          :const:`None`, ``name`` will be used, modified by the SGE if
-          it is already the unique identifier of another sprite.
-
         All other arguments set the respective initial attributes of the
         sprite.  See the documentation for :class:`Sprite` for more
         information.
-
         """
-        sprites = sge.game.sprites.copy()
-
+        self.rd = {}
         self.name = name
-        self._transparent = None
-        self._baseimages = []
-        self._images = []
-        self._masks = {}
+        self.__transparent = None
+        self.rd["baseimages"] = []
+        self.rd["images"] = []
+        self.rd["masks"] = {}
 
         fname_single = None
         fname_frames = []
         fname_strip = None
+        errlist = []
 
         if name is not None:
-            if ID is not None:
-                self.id = ID
-            else:
-                self.id = self.name
-
-                i = 0
-                while self.id in sprites:
-                    i += 1
-                    self.id = "{}{}".format(self.name, i)
-
             for path in sge.image_directories:
                 if os.path.isdir(path):
                     fnames = os.listdir(path)
@@ -296,23 +281,23 @@ class Sprite(object):
                 # Load the single image
                 try:
                     img = pygame.image.load(fname_single)
-                except pygame.error:
-                    pass
+                except pygame.error as e:
+                    errlist.append(e)
                 else:
-                    self._baseimages.append(img)
+                    self.rd["baseimages"].append(img)
 
-            if not self._baseimages and any(fname_frames):
+            if not self.rd["baseimages"] and any(fname_frames):
                 # Load the multiple images
                 for fname in fname_frames:
                     if fname:
                         try:
                             img = pygame.image.load(fname)
-                        except pygame.error:
-                            pass
+                        except pygame.error as e:
+                            errlist.append(e)
                         else:
-                            self._baseimages.append(img)
+                            self.rd["baseimages"].append(img)
 
-            if not self._baseimages and fname_strip:
+            if not self.rd["baseimages"] and fname_strip:
                 # Load the strip (sprite sheet)
                 root, ext = os.path.splitext(os.path.basename(fname_strip))
                 assert '-' in root or '_' in root
@@ -325,24 +310,30 @@ class Sprite(object):
 
                 try:
                     sheet = pygame.image.load(fname_strip)
-                except pygame.error:
-                    pass
+                except pygame.error as e:
+                    errlist.append(e)
                 else:
                     assert split[1][5:].isdigit()
                     n = int(split[1][5:])
 
                     img_w = max(1, sheet.get_width()) // n
                     img_h = max(1, sheet.get_height())
-                    for x in range(0, img_w * n, img_w):
+                    for x in six.moves.range(0, img_w * n, img_w):
                         rect = pygame.Rect(x, 0, img_w, img_h)
                         img = sheet.subsurface(rect)
-                        self._baseimages.append(img)
+                        self.rd["baseimages"].append(img)
 
-            if not self._baseimages:
+            if not self.rd["baseimages"]:
                 print("Directories searched:")
                 for d in sge.image_directories:
                     print(os.path.normpath(os.path.abspath(d)))
-                msg = 'Files for sprite name "{}" not found.'.format(name)
+                print("Pygame errors during search:")
+                if errlist:
+                    for e in errlist:
+                        print(e)
+                else:
+                    print("None")
+                msg = 'Supported file(s) for sprite name "{}" not found.'.format(name)
                 raise IOError(msg)
         else:
             # Name is None; default to a blank rectangle.
@@ -351,28 +342,22 @@ class Sprite(object):
             if height is None:
                 height = 32
 
-            self._w = width
-            self._h = height
+            self.__w = width
+            self.__h = height
 
             # Choose name
             self.name = "sge-pygame-dynamicsprite"
-            if ID is not None:
-                self.id = ID
-            else:
-                self.id = 0
-                while self.id in sprites:
-                    self.id += 1
 
             self.append_frame()
 
         if width is None:
             width = 1
-            for image in self._baseimages:
+            for image in self.rd["baseimages"]:
                 width = max(width, image.get_width())
 
         if height is None:
             height = 1
-            for image in self._baseimages:
+            for image in self.rd["baseimages"]:
                 height = max(height, image.get_height())
 
         if bbox_width is None:
@@ -381,54 +366,53 @@ class Sprite(object):
         if bbox_height is None:
             bbox_height = height
 
-        self._w = width
-        self._h = height
-        self._set_size()
+        self.__w = width
+        self.__h = height
+        s_set_size(self)
         self.origin_x = origin_x
         self.origin_y = origin_y
-        self._transparent = transparent
+        self.__transparent = transparent
         self.fps = fps
         self.bbox_x = bbox_x
         self.bbox_y = bbox_y
         self.bbox_width = bbox_width
         self.bbox_height = bbox_height
-        self._locked = False
-        self._refresh()
-        sprites[self.id] = self
-        sge.game.sprites = sprites
+        self.rd["locked"] = False
+        s_refresh(self)
 
     def append_frame(self):
         """Append a new blank frame to the end of the sprite."""
         img = pygame.Surface((self.width, self.height), pygame.SRCALPHA)
         img.fill(pygame.Color(0, 0, 0, 0))
-        self._baseimages.append(img)
+        self.rd["baseimages"].append(img)
 
     def insert_frame(self, frame):
-        """Insert a new blank frame into the sprite.
+        """
+        Insert a new blank frame into the sprite.
 
         Arguments:
 
         - ``frame`` -- The frame of the sprite to insert the new frame
           in front of, where ``0`` is the first frame.
-
         """
         img = pygame.Surface((self.width, self.height), pygame.SRCALPHA)
         img.fill(pygame.Color(0, 0, 0, 0))
-        self._baseimages.insert(frame, img)
+        self.rd["baseimages"].insert(frame, img)
 
     def delete_frame(self, frame):
-        """Delete a frame from the sprite.
+        """
+        Delete a frame from the sprite.
 
         Arguments:
 
         - ``frame`` -- The frame of the sprite to delete, where ``0`` is
           the first frame.
-
         """
-        del self._baseimages[frame]
+        del self.rd["baseimages"][frame]
 
     def draw_dot(self, x, y, color, frame=None):
-        """Draw a single-pixel dot on the sprite.
+        """
+        Draw a single-pixel dot on the sprite.
 
         Arguments:
 
@@ -441,7 +425,6 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         if not isinstance(color, sge.Color):
             e = "`{}` is not a sge.Color object.".format(repr(color))
@@ -451,21 +434,22 @@ class Sprite(object):
         y = int(round(y))
         pg_color = pygame.Color(*color)
         if color.alpha == 255:
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
-                    self._baseimages[i].set_at((x, y), pg_color)
+                    self.rd["baseimages"][i].set_at((x, y), pg_color)
         else:
             stamp = pygame.Surface((1, 1), pygame.SRCALPHA)
             stamp.fill(pg_color)
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
-                    self._baseimages[i].blit(stamp, (x, y))
+                    self.rd["baseimages"][i].blit(stamp, (x, y))
 
-        self._refresh()
+        s_refresh(self)
 
     def draw_line(self, x1, y1, x2, y2, color, thickness=1, anti_alias=False,
                   frame=None):
-        """Draw a line segment on the sprite.
+        """
+        Draw a line segment on the sprite.
 
         Arguments:
 
@@ -484,7 +468,6 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         if not isinstance(color, sge.Color):
             e = "`{}` is not a sge.Color object.".format(repr(color))
@@ -499,13 +482,13 @@ class Sprite(object):
         thickness = abs(thickness)
 
         if color.alpha == 255:
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
                     if anti_alias and thickness == 1:
-                        pygame.draw.aaline(self._baseimages[i], pg_color,
+                        pygame.draw.aaline(self.rd["baseimages"][i], pg_color,
                                            (x1, y1), (x2, y2))
                     else:
-                        pygame.draw.line(self._baseimages[i], pg_color,
+                        pygame.draw.line(self.rd["baseimages"][i], pg_color,
                                          (x1, y1), (x2, y2), thickness)
         else:
             stamp = pygame.Surface((self.width, self.height), pygame.SRCALPHA)
@@ -516,15 +499,16 @@ class Sprite(object):
                 pygame.draw.line(stamp, pg_color, (x1, y1), (x2, y2),
                                  thickness)
 
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
-                    self._baseimages[i].blit(stamp, (0, 0))
+                    self.rd["baseimages"][i].blit(stamp, (0, 0))
 
-        self._refresh()
+        s_refresh(self)
 
     def draw_rectangle(self, x, y, width, height, fill=None, outline=None,
                        outline_thickness=1, frame=None):
-        """Draw a rectangle on the sprite.
+        """
+        Draw a rectangle on the sprite.
 
         Arguments:
 
@@ -543,7 +527,6 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         if fill is not None and not isinstance(fill, sge.Color):
             e = "`{}` is not a sge.Color object.".format(repr(fill))
@@ -572,14 +555,14 @@ class Sprite(object):
 
         if ((fill is None or fill.alpha == 255) and
                 (outline is None or outline.alpha == 255)):
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
                     if fill is not None:
-                        self._baseimages[i].fill(pg_fill, rect)
+                        self.rd["baseimages"][i].fill(pg_fill, rect)
 
                     if outline is not None:
-                        pygame.draw.rect(self._baseimages[i], pg_outl, rect,
-                                         outline_thickness)
+                        pygame.draw.rect(self.rd["baseimages"][i], pg_outl,
+                                         rect, outline_thickness)
         else:
             stamp = pygame.Surface((self.width, self.height), pygame.SRCALPHA)
             stamp.fill(pygame.Color(0, 0, 0, 0))
@@ -588,15 +571,16 @@ class Sprite(object):
             if outline is not None:
                 pygame.draw.rect(stamp, pg_outl, rect, outline_thickness)
 
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
-                    self._baseimages[i].blit(stamp, (0, 0))
+                    self.rd["baseimages"][i].blit(stamp, (0, 0))
 
-        self._refresh()
+        s_refresh(self)
 
     def draw_ellipse(self, x, y, width, height, fill=None, outline=None,
                      outline_thickness=1, anti_alias=False, frame=None):
-        """Draw an ellipse on the sprite.
+        """
+        Draw an ellipse on the sprite.
 
         Arguments:
 
@@ -616,7 +600,6 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         if fill is not None and not isinstance(fill, sge.Color):
             e = "`{}` is not a sge.Color object.".format(repr(fill))
@@ -645,14 +628,15 @@ class Sprite(object):
 
         if ((fill is None or fill.alpha == 255) and
                 (outline is None or outline.alpha == 255)):
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
                     if fill is not None:
-                        pygame.draw.ellipse(self._baseimages[i], pg_fill, rect)
+                        pygame.draw.ellipse(self.rd["baseimages"][i], pg_fill,
+                                            rect)
 
                     if outline is not None:
-                        pygame.draw.ellipse(self._baseimages[i], pg_outl, rect,
-                                            outline_thickness)
+                        pygame.draw.ellipse(self.rd["baseimages"][i], pg_outl,
+                                            rect, outline_thickness)
         else:
             stamp = pygame.Surface((self.width, self.height), pygame.SRCALPHA)
             stamp.fill(pygame.Color(0, 0, 0, 0))
@@ -661,15 +645,16 @@ class Sprite(object):
             if outline is not None:
                 pygame.draw.ellipse(stamp, pg_outl, rect, outline_thickness)
 
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
-                    self._baseimages[i].blit(stamp, (0, 0))
+                    self.rd["baseimages"][i].blit(stamp, (0, 0))
 
-        self._refresh()
+        s_refresh(self)
 
     def draw_circle(self, x, y, radius, fill=None, outline=None,
                     outline_thickness=1, anti_alias=False, frame=None):
-        """Draw a circle on the sprite.
+        """
+        Draw a circle on the sprite.
 
         Arguments:
 
@@ -688,7 +673,6 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         if fill is not None and not isinstance(fill, sge.Color):
             e = "`{}` is not a sge.Color object.".format(repr(fill))
@@ -715,14 +699,14 @@ class Sprite(object):
 
         if ((fill is None or fill.alpha == 255) and
                 (outline is None or outline.alpha == 255)):
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
                     if fill is not None:
-                        pygame.draw.circle(self._baseimages[i], pg_fill,
+                        pygame.draw.circle(self.rd["baseimages"][i], pg_fill,
                                            (x, y), radius)
 
                     if outline is not None:
-                        pygame.draw.circle(self._baseimages[i], pg_outl,
+                        pygame.draw.circle(self.rd["baseimages"][i], pg_outl,
                                            (x, y), radius, outline_thickness)
         else:
             stamp = pygame.Surface((self.width, self.height), pygame.SRCALPHA)
@@ -733,14 +717,92 @@ class Sprite(object):
                 pygame.draw.circle(stamp, pg_outl, (x, y), radius,
                                    outline_thickness)
 
-            for i in range(self.frames):
+            for i in six.moves.range(self.frames):
                 if frame is None or frame % self.frames == i:
-                    self._baseimages[i].blit(stamp, (0, 0))
+                    self.rd["baseimages"][i].blit(stamp, (0, 0))
 
-        self._refresh()
+        s_refresh(self)
+
+    def draw_polygon(self, points, fill=None, outline=None,
+                     outline_thickness=1, anti_alias=False, frame=None):
+        """
+        Draw a polygon on the sprite.
+
+        Arguments:
+
+        - ``points`` -- A list of points relative to the sprite to
+          position each of the polygon's angles.  Each point should be a
+          tuple in the form ``(x, y)``, where x is the horizontal
+          location and y is the vertical location.
+        - ``fill`` -- A :class:`sge.Color` object representing the color
+          of the fill of the polygon.
+        - ``outline`` -- A :class:`sge.Color` object representing the
+          color of the outline of the polygon.
+        - ``outline_thickness`` -- The thickness of the outline of the
+          polygon.
+        - ``anti_alias`` -- Whether or not anti-aliasing should be used.
+        - ``frame`` -- The frame of the sprite to draw on, where ``0``
+          is the first frame; set to :const:`None` to draw on all
+          frames.
+        """
+        if fill is not None and not isinstance(fill, sge.Color):
+            e = "`{}` is not a sge.Color object.".format(repr(fill))
+            raise TypeError(e)
+        if outline is not None and not isinstance(outline, sge.Color):
+            e = "`{}` is not a sge.Color object.".format(repr(outline))
+            raise TypeError(e)
+
+        points = [(int(round(x)), int(round(y))) for (x, y) in points]
+        outline_thickness = abs(outline_thickness)
+        if outline_thickness == 0:
+            outline = None
+
+        if fill is None and outline is None:
+            # There's no point in trying in this case.
+            return
+
+        if fill is not None:
+            pg_fill = pygame.Color(*fill)
+        if outline is not None:
+            pg_outl = pygame.Color(*outline)
+
+        if ((fill is None or fill.alpha == 255) and
+                (outline is None or outline.alpha == 255)):
+            for i in six.moves.range(self.frames):
+                if frame is None or frame % self.frames == i:
+                    if fill is not None:
+                        pygame.draw.polygon(self.rd["baseimages"][i], pg_fill,
+                                            points, 0)
+
+                    if outline is not None:
+                        if anti_alias and outline_thickness == 1:
+                            pygame.draw.aalines(self.rd["baseimages"][i],
+                                                pg_outl, True, points)
+                        else:
+                            pygame.draw.polygon(self.rd["baseimages"][i],
+                                                pg_outl, points,
+                                                outline_thickness)
+        else:
+            stamp = pygame.Surface((self.width, self.height), pygame.SRCALPHA)
+            stamp.fill(pygame.Color(0, 0, 0, 0))
+            if fill is not None:
+                pygame.draw.polygon(stamp, pg_fill, points, 0)
+            if outline is not None:
+                if anti_alias and outline_thickness == 1:
+                    pygame.draw.aalines(stamp, pg_outl, True, points)
+                else:
+                    pygame.draw.polygon(stamp, pg_outl, points,
+                                        outline_thickness)
+
+            for i in six.moves.range(self.frames):
+                if frame is None or frame % self.frames == i:
+                    self.rd["baseimages"][i].blit(stamp, (0, 0))
+
+        s_refresh(self)
 
     def draw_sprite(self, sprite, image, x, y, frame=None, blend_mode=None):
-        """Draw another sprite on the sprite.
+        """
+        Draw another sprite on the sprite.
 
         Arguments:
 
@@ -772,30 +834,27 @@ class Sprite(object):
           - :data:`sge.BLEND_RGB_MAXIMUM`
 
           :const:`None` is treated as :data:`sge.BLEND_NORMAL`.
-
         """
-        x = int(round(x))
-        y = int(round(y))
-        if not isinstance(sprite, sge.Sprite):
-            sprite = sge.game.sprites[sprite]
+        x = int(round(x - sprite.origin_x))
+        y = int(round(y - sprite.origin_y))
 
-        x -= int(round(sprite.origin_x))
-        y -= int(round(sprite.origin_y))
-        image %= len(sprite._baseimages)
+        image %= sprite.frames
 
-        pygame_flags = sge._get_blend_flags(blend_mode)
+        pygame_flags = _get_blend_flags(blend_mode)
 
-        for i in range(self.frames):
+        for i in six.moves.range(self.frames):
             if frame is None or frame % self.frames == i:
-                self._baseimages[i].blit(sprite._baseimages[image], (x, y),
-                                         None, pygame_flags)
+                self.rd["baseimages"][i].blit(
+                    s_set_transparency(sprite, sprite.rd["baseimages"][image]),
+                    (x, y), None, pygame_flags)
 
-        self._refresh()
+        s_refresh(self)
 
     def draw_text(self, font, text, x, y, width=None, height=None,
                   color=sge.Color("black"), halign=sge.ALIGN_LEFT,
                   valign=sge.ALIGN_TOP, anti_alias=True, frame=None):
-        """Draw text on the sprite.
+        """
+        Draw text on the sprite.
 
         Arguments:
 
@@ -854,7 +913,6 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         if not isinstance(font, sge.Font):
             font = sge.game.fonts[font]
@@ -865,7 +923,7 @@ class Sprite(object):
         x = int(round(x))
         y = int(round(y))
 
-        lines = font._split_text(text, width)
+        lines = f_split_text(font, text, width)
         width = font.get_width(text, width, height)
         height = font.get_height(text, width, height)
         fake_height = font.get_height(text, width)
@@ -875,11 +933,11 @@ class Sprite(object):
         text_rect = text_surf.get_rect()
         box_rect = box_surf.get_rect()
 
-        for i in range(len(lines)):
-            rendered_text = font._font.render(lines[i], anti_alias,
-                                              pygame.Color(*color))
+        for i in six.moves.range(len(lines)):
+            rendered_text = font.rd["font"].render(lines[i], anti_alias,
+                                                   pygame.Color(*color))
             rect = rendered_text.get_rect()
-            rect.top = i * font._font.get_linesize()
+            rect.top = i * font.rd["font"].get_linesize()
 
             if halign == sge.ALIGN_LEFT:
                 rect.left = text_rect.left
@@ -917,14 +975,15 @@ class Sprite(object):
         else:
             box_rect.top = y
 
-        for i in range(self.frames):
+        for i in six.moves.range(self.frames):
             if frame is None or frame % self.frames == i:
-                self._baseimages[i].blit(box_surf, box_rect)
+                self.rd["baseimages"][i].blit(box_surf, box_rect)
 
-        self._refresh()
+        s_refresh(self)
 
     def draw_erase(self, x, y, width, height, frame=None):
-        """Erase part of the sprite.
+        """
+        Erase part of the sprite.
 
         Arguments:
 
@@ -937,33 +996,33 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to erase from, where
           ``0`` is the first frame; set to :const:`None` to erase from
           all frames.
-
         """
-        for i in range(self.frames):
+        for i in six.moves.range(self.frames):
             if frame is None or frame % self.frames == i:
-                if self._baseimages[i].get_flags() & pygame.SRCALPHA:
+                if self.rd["baseimages"][i].get_flags() & pygame.SRCALPHA:
                     color = pygame.Color(0, 0, 0, 0)
                 else:
-                    color = self._baseimages[i].get_colorkey()
+                    color = self.rd["baseimages"][i].get_colorkey()
 
                 rect = pygame.Rect(x, y, width, height)
-                self._baseimages[i].fill(color, rect)
+                self.rd["baseimages"][i].fill(color, rect)
 
-        self._refresh()
+        s_refresh(self)
 
     def draw_clear(self, frame=None):
-        """Erase everything from the sprite.
+        """
+        Erase everything from the sprite.
 
         Arguments:
 
         - ``frame`` -- The frame of the sprite to clear, where ``0`` is
           the first frame; set to :const:`None` to clear all frames.
-
         """
         self.draw_erase(0, 0, self.width, self.height, frame)
 
     def draw_lock(self):
-        """Lock the sprite for continuous drawing.
+        """
+        Lock the sprite for continuous drawing.
 
         Use this method to "lock" the sprite for being drawn on several
         times in a row.  What exactly this does depends on the
@@ -984,24 +1043,24 @@ class Sprite(object):
            and as severe as crashing the program, depending on the SGE
            implementation.  Always call :meth:`sge.Sprite.draw_unlock`
            immediately after you're done drawing for a while.
-
         """
-        if not self._locked:
-            self._locked = True
+        if not self.rd["locked"]:
+            self.rd["locked"] = True
 
     def draw_unlock(self):
-        """Unlock the sprite.
+        """
+        Unlock the sprite.
 
         Use this method to "unlock" the sprite after it has been
         "locked" for continuous drawing by :meth:`sge.Sprite.draw_lock`.
-
         """
-        if self._locked:
-            self._locked = False
-            self._refresh()
+        if self.rd["locked"]:
+            self.rd["locked"] = False
+            s_refresh(self)
 
     def save(self, fname):
-        """Save the sprite to an image file.
+        """
+        Save the sprite to an image file.
 
         Arguments:
 
@@ -1012,7 +1071,6 @@ class Sprite(object):
         If the sprite has multiple frames, the image file saved will be
         a horizontal reel of each of the frames from left to right with
         no space in between the frames.
-
         """
         # Assuming self.width and self.height are the size of all
         # surfaces in _baseimages (this should be the case).
@@ -1021,8 +1079,8 @@ class Sprite(object):
         reel = pygame.Surface((w, h), pygame.SRCALPHA)
         reel.fill(pygame.Color(0, 0, 0, 0))
 
-        for i in range(self.frames):
-            reel.blit(self._baseimages[i], (self.width * i, 0))
+        for i in six.moves.range(self.frames):
+            reel.blit(self.rd["baseimages"][i], (self.width * i, 0))
 
         try:
             pygame.image.save(reel, fname)
@@ -1031,27 +1089,13 @@ class Sprite(object):
                 os.path.normpath(os.path.realpath(fname)))
             raise IOError(m)
 
-    def destroy(self):
-        """Destroy the sprite.
-
-        .. note::
-
-           If the sprite is being used, for example, by a
-           :class:`sge.Object` object, it will not be completely
-           destroyed until this use stops.
-
-        """
-        sprites = sge.game.sprites.copy()
-        if self.id in sprites:
-            del sprites[self.id]
-        sge.game.sprites = sprites
-
     @classmethod
-    def from_tileset(cls, name, ID=None, x=0, y=0, columns=1, rows=1, xsep=0,
-                     ysep=0, width=1, height=1, origin_x=0, origin_y=0,
+    def from_tileset(cls, name, x=0, y=0, columns=1, rows=1, xsep=0, ysep=0,
+                     width=1, height=1, origin_x=0, origin_y=0,
                      transparent=True, fps=0, bbox_x=None, bbox_y=None,
                      bbox_width=None, bbox_height=None):
-        """Return a sprite based on the tiles in a tileset.
+        """
+        Return a sprite based on the tiles in a tileset.
 
         Arguments:
 
@@ -1075,34 +1119,33 @@ class Sprite(object):
         Each tile in the tileset becomes a subimage of the returned
         sprite, ordered first from left to right and then from top to
         bottom.
-
         """
-        self = cls(name, ID=ID, width=width, height=height, origin_x=origin_x,
+        self = cls(name, width=width, height=height, origin_x=origin_x,
                    origin_y=origin_y, transparent=transparent, fps=fps,
                    bbox_x=bbox_x, bbox_y=bbox_y, bbox_width=bbox_width,
                    bbox_height=bbox_height)
         tileset = Sprite(name, origin_x=x, origin_y=y)
 
-        for i in range(1, rows):
-            for j in range(1, columns):
+        for i in six.moves.range(1, rows):
+            for j in six.moves.range(1, columns):
                 self.append_frame()
 
         self.draw_clear()
 
-        for i in range(rows):
-            for j in range(columns):
+        for i in six.moves.range(rows):
+            for j in six.moves.range(columns):
                 frame = i * columns + j
                 x_ = (width + xsep) * j
                 y_ = (height + ysep) * i
                 self.draw_sprite(tileset, 0, -x_ - self.origin_x,
                                  -y_ - self.origin_y, frame=frame)
 
-        tileset.destroy()
         return self
 
     @classmethod
     def from_screenshot(cls, x=0, y=0, width=None, height=None):
-        """Return the current display on the screen as a sprite.
+        """
+        Return the current display on the screen as a sprite.
 
         Arguments:
 
@@ -1121,7 +1164,6 @@ class Sprite(object):
         a file, the easiest way to do that is::
 
             sge.Sprite.from_screenshot().save("foo.png")
-
         """
         if width is None:
             width = sge.game.width - x
@@ -1129,122 +1171,6 @@ class Sprite(object):
             height = sge.game.height - y
 
         sprite = cls(width=width, height=height)
-        sprite._baseimages[0].blit(sge.game._display_surface, (-x, -y))
-        sprite._refresh()
+        sprite.rd["baseimages"][0].blit(r.game_display_surface, (-x, -y))
+        s_refresh(sprite)
         return sprite
-
-    def _set_size(self):
-        # Adjust the size of the base images.  Note: this change is
-        # destructive and irreversible.  It is necessary for the drawing
-        # methods to work properly, specifically whenever ``width`` and
-        # ``height`` are set.  As a result, setting ``width`` and
-        # ``height`` is destructive in this implementation.
-        width = int(round(self.width))
-        height = int(round(self.height))
-        for i in range(self.frames):
-            if sge.game.scale_smooth:
-                try:
-                    self._baseimages[i] = pygame.transform.smoothscale(
-                        self._baseimages[i], (width, height))
-                except pygame.error:
-                    self._baseimages[i] = pygame.transform.scale(
-                        self._baseimages[i], (width, height))
-            else:
-                self._baseimages[i] = pygame.transform.scale(
-                    self._baseimages[i], (width, height))
-
-    def _refresh(self):
-        # Set the _images list based on the variables.
-        if not self._locked:
-            self._images = []
-            for image in self._baseimages:
-                img = self._set_transparency(image)
-                img = sge._scale(img, self.width, self.height)
-                self._images.append({(1, 1, 0, 255, None): img})
-
-    def _set_transparency(self, image):
-        # Return a copy of the surface with transparency properly set
-        # for this sprite's settings.
-        if self.transparent and image.get_width() > 0:
-            if image.get_flags() & pygame.SRCALPHA:
-                return image.convert_alpha()
-            else:
-                colorkey_img = image.convert()
-                color = image.get_at((image.get_width() - 1, 0))
-                colorkey_img.set_colorkey(color, pygame.RLEACCEL)
-                return colorkey_img
-        else:
-            return image.convert()
-
-    def _get_image(self, num, xscale=1, yscale=1, rotation=0, alpha=255,
-                   blend=None):
-        num %= len(self._images)
-        # Return the properly sized surface.
-        t = (xscale, yscale, rotation, alpha,
-             tuple(blend) if blend is not None else blend)
-        if t in self._images[num]:
-            return self._images[num][t]
-        else:
-            # Hasn't been scaled to this size yet
-            if xscale != 0 and yscale != 0:
-                img = self._set_transparency(self._baseimages[num])
-                xflip = xscale < 0
-                yflip = yscale < 0
-                img = pygame.transform.flip(img, xflip, yflip)
-                img = sge._scale(img, self.width * abs(xscale),
-                                 self.height * abs(yscale))
-
-                if rotation != 0:
-                    img = pygame.transform.rotate(img, rotation)
-
-                if alpha < 255:
-                    if img.get_flags() & pygame.SRCALPHA:
-                        # Have to do this the more difficult way.
-                        img.fill((0, 0, 0, 255 - alpha), None,
-                                 pygame.BLEND_RGBA_SUB)
-                    else:
-                        img.set_alpha(alpha, pygame.RLEACCEL)
-
-                if blend is not None:
-                    img.fill(pygame.Color(*blend), None,
-                             pygame.BLEND_RGB_MULT)
-            else:
-                img = pygame.Surface((1, 1))
-                img.set_colorkey((0, 0, 0), pygame.RLEACCEL)
-
-            self._images[num][t] = img
-            return img
-
-    def _get_precise_mask(self, num, xscale, yscale, rotation):
-        # Return a precise mask (2D list of True/False values) for the
-        # given image index.
-        mask_id = (num, xscale, yscale, rotation)
-        if mask_id in self._masks:
-            return self._masks[mask_id]
-        else:
-            image = self._set_transparency(self._baseimages[num])
-            xflip = xscale < 0
-            yflip = yscale < 0
-            image = pygame.transform.flip(image, xflip, yflip)
-            image = pygame.transform.scale(image, (self.width * abs(xscale),
-                                                   self.height * abs(yscale)))
-            if rotation:
-                image = pygame.transform.rotate(image, rotation)
-
-            image.lock()
-            mask = []
-            if image.get_flags() & pygame.SRCALPHA:
-                for x in range(image.get_width()):
-                    mask.append([])
-                    for y in range(image.get_height()):
-                        mask[x].append(image.get_at((x, y)).a > 0)
-            else:
-                colorkey = image.get_colorkey()
-                for x in range(image.get_width()):
-                    mask.append([])
-                    for y in range(image.get_height()):
-                        mask[x].append(image.get_at((x, y)) == colorkey)
-
-            image.unlock()
-            self._masks[mask_id] = mask
-            return mask
