@@ -34,24 +34,6 @@ contribution to a free society.
 SGE Concepts
 ============
 
-Naming Conventions
-------------------
-
-There are many cases where you will want to derive a class from a SGE
-class.  Since there can be multiple implementations of the SGE, it can
-be easy when doing so to overwrite a special variable used by some
-implementations internally, which can be disastrous.  To avoid such
-occasions, implementations are expected to never introduce any attribute
-names which are not explicitly mentioned in the documentation for a
-class unless the new attribute names are preceded by an underscore, as
-in the hypothetical attribute name ``_foo``.  This naming convention
-will protect users of the SGE from unexpected errors provided that they
-do not use such names themselves.
-
-A suggested convention for users of the SGE to use for "private"
-attributes in place of the usual leading underscore  is to precede these
-attributes with ``v_`` or ``p_``.
-
 Events
 ------
 
@@ -269,22 +251,26 @@ Global Variables and Constants
 
    A list of directories where images can be found.  Default is
    ``./data/images``, ``./data/sprites``, or ``./data/backgrounds``,
-   where ``.`` is the program directory.
+   where ``.`` is the program directory.  Directories within the
+   listed directories are not included.
 
 .. data:: sge.font_directories
 
    A list of directories where font files can be found.  Default is
-   ``./data/fonts``, where ``.`` is the program directory.
+   ``./data/fonts``, where ``.`` is the program directory.  Directories
+   within the listed directories are not included.
 
 .. data:: sge.sound_directories
 
    A list of directories where sounds can be found.  Default is
-   ``./data/sounds``, where ``.`` is the program directory.
+   ``./data/sounds``, where ``.`` is the program directory.  Directories
+   within the listed directories are not included.
 
 .. data:: sge.music_directories
 
    A list of directories where music files can be found.  Default is
-   ``./data/music``, where ``.`` is the program directory.
+   ``./data/music``, where ``.`` is the program directory.  Directories
+   within the listed directories are not included.
 
 Information specific to the Pygame SGE
 ======================================
@@ -359,10 +345,12 @@ Missing Features
 
 :meth:`sge.Sprite.draw_line`, :meth:`sge.Room.project_line`, and
 :meth:`sge.Game.project_line` support anti-aliasing for lines with a
-thickness of 1 only.  :meth:`sge.Sprite.draw_text`,
-:meth:`sge.Room.project_text`, and :meth:`sge.Game.project_text` support
-anti-aliasing in all cases.  No other drawing or projecting methods
-support anti-aliasing.
+thickness of 1 only.  :meth:`sge.Sprite.draw_polygon`,
+:meth:`sge.Room.project_polygon`, and :meth:`sge.Game.project_polygon`
+support anti-aliasing for outlines of polygons with a thickness of 1
+only.  :meth:`sge.Sprite.draw_text`, :meth:`sge.Room.project_text`,
+and :meth:`sge.Game.project_text` support anti-aliasing in all cases.
+No other drawing or projecting methods support anti-aliasing.
 
 :data:`sge.BLEND_RGBA_SCREEN` and :data:`sge.BLEND_RGB_SCREEN` are
 unsupported. If one of these blend modes is attempted, normal blending
@@ -374,7 +362,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
-__version__ = "0.13"
+__version__ = "0.14"
 
 import sys
 import os
@@ -501,7 +489,7 @@ from sge.Music import Music
 from sge.Object import Object, Mouse
 from sge.Room import Room
 from sge.View import View
-from sge import collision, input, joystick, keyboard, mouse
+from sge import collision, input, joystick, keyboard, mouse, r
 
 
 __all__ = [
@@ -533,49 +521,7 @@ font_directories = [os.path.join(PROGRAM_DIR, 'data', 'fonts')]
 sound_directories = [os.path.join(PROGRAM_DIR, 'data', 'sounds')]
 music_directories = [os.path.join(PROGRAM_DIR, 'data', 'music')]
 
-hardware_rendering = False
-
 # Uncomment this line to tell SDL to center the window.  Disabled by
 # default because it seems to cause some weird behavior with window
 # resizing on at least some systems.
 #os.environ['SDL_VIDEO_CENTERED'] = '1'
-
-
-def _scale(surface, width, height):
-    # Scale the given surface to the given width and height.
-    if surface.get_width() == width and surface.get_height() == height:
-        return surface.copy()
-
-    width = int(round(width))
-    height = int(round(height))
-    if game.scale_smooth:
-        try:
-            new_surf = pygame.transform.smoothscale(surface, (width, height))
-        except (pygame.error, ValueError):
-            new_surf = pygame.transform.scale(surface, (width, height))
-    else:
-        new_surf = pygame.transform.scale(surface, (width, height))
-
-    return new_surf
-
-
-def _get_blend_flags(blend_mode):
-    # Return the appropriate Pygame flags for the given blend mode.
-    if blend_mode is not None and blend_mode & BLEND_SCREEN:
-        w = "Screen blend mode not supported. Normal blending used instead."
-        warnings.warn(w)
-
-    pygame_flags = {
-        BLEND_RGBA_ADD: pygame.BLEND_RGBA_ADD,
-        BLEND_RGBA_SUBTRACT: pygame.BLEND_RGBA_SUB,
-        BLEND_RGBA_MULTIPLY: pygame.BLEND_RGBA_MULT,
-        BLEND_RGBA_MINIMUM: pygame.BLEND_RGBA_MIN,
-        BLEND_RGBA_MAXIMUM: pygame.BLEND_RGBA_MAX,
-        BLEND_RGB_ADD: pygame.BLEND_RGB_ADD,
-        BLEND_RGB_SUBTRACT: pygame.BLEND_RGB_SUB,
-        BLEND_RGB_MULTIPLY: pygame.BLEND_RGB_MULT,
-        BLEND_RGB_MINIMUM: pygame.BLEND_RGB_MIN,
-        BLEND_RGB_MAXIMUM: pygame.BLEND_RGB_MAX
-        }.get(blend_mode, 0)
-
-    return pygame_flags
