@@ -28,24 +28,19 @@ from __future__ import unicode_literals
 
 import math
 
+import six
+
 import sge
-from sge import six
+from sge import r
 
 
 __all__ = ["rectangles_collide", "masks_collide", "rectangle", "ellipse",
            "circle", "line"]
 
 
-class _cache(object):
-
-    rectangle_masks = {}
-    ellipse_masks = {}
-    circle_masks = {}
-    line_masks = {}
-
-
 def rectangles_collide(x1, y1, w1, h1, x2, y2, w2, h2):
-    """Return whether or not two rectangles collide.
+    """
+    Return whether or not two rectangles collide.
 
     Arguments:
 
@@ -57,13 +52,13 @@ def rectangles_collide(x1, y1, w1, h1, x2, y2, w2, h2):
     - ``y2`` -- The vertical position of the second rectangle.
     - ``w2`` -- The width of the second rectangle.
     - ``h2`` -- The height of the second rectangle.
-
     """
     return (x1 < x2 + w2 and x1 + w1 > x2 and y1 < y2 + h2 and y1 + h1 > y2)
 
 
 def masks_collide(x1, y1, mask1, x2, y2, mask2):
-    """Return whether or not two masks collide.
+    """
+    Return whether or not two masks collide.
 
     Arguments:
 
@@ -81,7 +76,6 @@ def masks_collide(x1, y1, mask1, x2, y2, mask2):
 
     Masks are indexed as ``mask[x][y]``, where ``x`` is the column and
     ``y`` is the row.
-
     """
     if mask1 and mask2 and mask1[0] and mask2[0]:
         x1 = int(round(x1))
@@ -103,7 +97,8 @@ def masks_collide(x1, y1, mask1, x2, y2, mask2):
 
 
 def rectangle(x, y, w, h, other=None):
-    """Return a list of objects colliding with a rectangle.
+    """
+    Return a list of objects colliding with a rectangle.
 
     Arguments:
 
@@ -114,19 +109,18 @@ def rectangle(x, y, w, h, other=None):
     - ``other`` -- What to check for collisions with.  See the
       documentation for :meth:`sge.StellarClass.collision` for more
       information.
-
     """
     room = sge.game.current_room
-    areas = _get_rectangle_collision_areas(x, y, w, h)
-    others = _get_others(areas, other)
+    areas = r._get_rectangle_collision_areas(x, y, w, h)
+    others = r._get_others(areas, other)
     collisions = []
     mask_id = (x, y, w, h)
 
-    if mask_id in _cache.rectangle_masks:
-        mask = _cache.rectangle_masks[mask_id]
+    if mask_id in r.cache.rectangle_masks:
+        mask = r.cache.rectangle_masks[mask_id]
     else:
         mask = [[True for j in six.moves.range(h)] for i in six.moves.range(w)]
-        _cache.rectangle_masks[mask_id] = mask
+        r.cache.rectangle_masks[mask_id] = mask
 
     for other in others:
         if other.collision_precise or other.collision_ellipse:
@@ -142,7 +136,8 @@ def rectangle(x, y, w, h, other=None):
 
 
 def ellipse(x, y, w, h, other=None):
-    """Return a list of objects colliding with an ellipse.
+    """
+    Return a list of objects colliding with an ellipse.
 
     Arguments:
 
@@ -155,16 +150,15 @@ def ellipse(x, y, w, h, other=None):
     - ``other`` -- What to check for collisions with.  See the
       documentation for :meth:`sge.StellarClass.collision` for more
       information.
-
     """
     room = sge.game.current_room
-    areas = _get_rectangle_collision_areas(x, y, w, h)
-    others = _get_others(areas, other)
+    areas = r._get_rectangle_collision_areas(x, y, w, h)
+    others = r._get_others(areas, other)
     collisions = []
     mask_id = (x, y, w, h)
 
-    if mask_id in _cache.ellipse_masks:
-        mask = _cache.ellipse_masks[mask_id]
+    if mask_id in r.cache.ellipse_masks:
+        mask = r.cache.ellipse_masks[mask_id]
     else:
         mask = [[False for j in six.moves.range(h)]
                 for i in six.moves.range(w)]
@@ -176,7 +170,7 @@ def ellipse(x, y, w, h, other=None):
                 if ((i - a) / a) ** 2 + ((j - b) / b) ** 2 <= 1:
                     mask[i][j] = True
 
-        _cache.ellipse_masks[mask_id] = mask
+        r.cache.ellipse_masks[mask_id] = mask
 
     for other in others:
         if masks_collide(x, y, mask, other.mask_x, other.mask_y,
@@ -187,7 +181,8 @@ def ellipse(x, y, w, h, other=None):
 
 
 def circle(x, y, radius, other=None):
-    """Return a list of objects colliding with a circle.
+    """
+    Return a list of objects colliding with a circle.
 
     Arguments:
 
@@ -197,17 +192,16 @@ def circle(x, y, radius, other=None):
     - ``other`` -- What to check for collisions with.  See the
       documentation for :meth:`sge.StellarClass.collision` for more
       information.
-
     """
     room = sge.game.current_room
     diameter = radius * 2
-    areas = _get_rectangle_collision_areas(x, y, diameter, diameter)
-    others = _get_others(areas, other)
+    areas = r._get_rectangle_collision_areas(x, y, diameter, diameter)
+    others = r._get_others(areas, other)
     collisions = []
     mask_id = (x, y, radius)
 
-    if mask_id in _cache.circle_masks:
-        mask = _cache.circle_masks[mask_id]
+    if mask_id in r.cache.circle_masks:
+        mask = r.cache.circle_masks[mask_id]
     else:
         mask = [[False for j in six.moves.range(diameter)]
                 for i in six.moves.range(diameter)]
@@ -217,7 +211,7 @@ def circle(x, y, radius, other=None):
                 if (i - x) ** 2 + (j - y) ** 2 <= radius ** 2:
                     mask[i][j] = True
 
-        _cache.circle_masks[mask_id] = mask
+        r.cache.circle_masks[mask_id] = mask
 
     for other in others:
         if masks_collide(x - radius, y - radius, mask, other.mask_x,
@@ -228,7 +222,8 @@ def circle(x, y, radius, other=None):
 
 
 def line(x1, y1, x2, y2, other=None):
-    """Return a list of objects colliding with a line segment.
+    """
+    Return a list of objects colliding with a line segment.
 
     Arguments:
 
@@ -243,20 +238,19 @@ def line(x1, y1, x2, y2, other=None):
     - ``other`` -- What to check for collisions with.  See the
       documentation for :meth:`sge.StellarClass.collision` for more
       information.
-
     """
     room = sge.game.current_room
     x = min(x1, x2)
     y = min(y1, y2)
     w = abs(x2 - x1)
     h = abs(y2 - y1)
-    areas = _get_rectangle_collision_areas(x, y, w, h)
-    others = _get_others(areas, other)
+    areas = r._get_rectangle_collision_areas(x, y, w, h)
+    others = r._get_others(areas, other)
     collisions = []
     mask_id = (w, h)
 
-    if mask_id in _cache.line_masks:
-        mask = _cache.line_masks[mask_id]
+    if mask_id in r.cache.line_masks:
+        mask = r.cache.line_masks[mask_id]
     else:
         mask = [[False for j in six.moves.range(h)]
                 for i in six.moves.range(w)]
@@ -268,7 +262,7 @@ def line(x1, y1, x2, y2, other=None):
             if 0 <= j < len(mask[i]):
                 mask[i][j] = True
 
-        _cache.line_masks[mask_id] = mask
+        r.cache.line_masks[mask_id] = mask
 
     for other in others:
         if masks_collide(x, y, mask, other.mask_x, other.mask_y,
@@ -276,60 +270,3 @@ def line(x1, y1, x2, y2, other=None):
             collisions.append(other)
 
     return collisions
-
-
-def _get_rectangle_collision_areas(x, y, w, h):
-    # Get a list of collision areas a rect is in.
-    room = sge.game.current_room
-    area_size = room._collision_area_size
-    areas_x_start = int(math.floor(x / area_size))
-    areas_x_num = int(math.ceil(w / area_size) + 1)
-    areas_y_start = int(math.floor(y / area_size))
-    areas_y_num = int(math.ceil(h / area_size) + 1)
-    areas = []
-
-    for i in six.moves.range(areas_x_start, areas_x_start + areas_x_num):
-        for j in six.moves.range(areas_y_start, areas_y_start + areas_y_num):
-            if (i >= 0 and j >= 0 and room._collision_areas and
-                    i < len(room._collision_areas) and
-                    j < len(room._collision_areas[0])):
-                areas.append((i, j))
-            elif None not in areas:
-                areas.append(None)
-
-    return areas
-
-
-def _get_others(areas, other=None):
-    room = sge.game.current_room
-    others = []
-
-    for area in areas:
-        if area is not None:
-            i, j = area
-            room_area = room._collision_areas[i][j]
-        else:
-            room_area = room._collision_area_void
-
-        for ref in room_area:
-            obj = ref()
-            if obj is not None:
-                if other is None:
-                    others.append(obj)
-                elif isinstance(other, sge.StellarClass):
-                    if obj is other:
-                        others.append(obj)
-                elif isinstance(other, (list, tuple)):
-                    if obj in other:
-                        others.append(obj)
-                elif other in sge.game.objects:
-                    if obj is sge.game.objects[other]:
-                        others.append(obj)
-                else:
-                    try:
-                        if isinstance(obj, other):
-                            others.append(obj)
-                    except TypeError:
-                        pass
-
-    return others
