@@ -25,9 +25,10 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import pygame
+import six
 
 import sge
-from sge import six
+from sge import r
 
 
 __all__ = ["refresh", "get_axis", "get_hat_x", "get_hat_y",
@@ -36,15 +37,15 @@ __all__ = ["refresh", "get_axis", "get_hat_x", "get_hat_y",
 
 
 def refresh():
-    """Refresh the SGE's knowledge of joysticks.
+    """
+    Refresh the SGE's knowledge of joysticks.
 
     Call this method to allow the SGE to use joysticks that were plugged
     in while the game was running.
-
     """
-    sge.game._joysticks = []
-    sge.game._js_names = {}
-    sge.game._js_ids = {}
+    r.game_joysticks = []
+    r.game_js_names = {}
+    r.game_js_ids = {}
     pygame.joystick.quit()
     pygame.joystick.init()
 
@@ -53,14 +54,18 @@ def refresh():
             joy = pygame.joystick.Joystick(i)
             joy.init()
             n = joy.get_name()
-            sge.game._joysticks.append(joy)
-            sge.game._js_names[i] = n
-            if n not in sge.game._js_ids:
-                sge.game._js_ids[n] = i
+            r.game_joysticks.append(joy)
+            r.game_js_names[i] = n
+            if n not in r.game_js_ids:
+                r.game_js_ids[n] = i
 
 
 def get_axis(joystick, axis):
-    """Return the position of a joystick axis.
+    """
+    Return the position of a joystick axis as a float from ``-1`` to
+    ``1``, where ``0`` is centered, ``-1`` is all the way to the left or
+    up, and ``1`` is all the way to the right or down.  Return ``0`` if
+    the requested joystick or axis does not exist.
 
     Arguments:
 
@@ -68,35 +73,21 @@ def get_axis(joystick, axis):
       is the first joystick, or the name of the joystick to check.
     - ``axis`` -- The number of the axis to check, where ``0`` is the
       first axis of the joystick.
-
-    Return a float from ``-1`` to ``1``, where ``0`` is centered, ``-1``
-    is all the way to the left or up, and ``1`` is all the way to the
-    right or down.  Return ``0`` if the requested joystick or axis does
-    not exist.
-
     """
     joystick = get_id(joystick)
 
-    if (joystick is not None and joystick < len(sge.game._joysticks) and
-            axis < sge.game._joysticks[joystick].get_numaxes()):
-        return sge.game._joysticks[joystick].get_axis(axis)
+    if (joystick is not None and joystick < len(r.game_joysticks) and
+            axis < r.game_joysticks[joystick].get_numaxes()):
+        return r.game_joysticks[joystick].get_axis(axis)
     else:
         return 0
 
 
-def _get_hat(joystick, hat):
-    # Return the position of a joystick HAT.
-    joystick = get_id(joystick)
-
-    if (joystick is not None and joystick < len(sge.game._joysticks) and
-            hat < sge.game._joysticks[joystick].get_numhats()):
-        return sge.game._joysticks[joystick].get_hat(hat)
-    else:
-        return (0, 0)
-
-
 def get_hat_x(joystick, hat):
-    """Return the horizontal position of a joystick hat (d-pad).
+    """
+    Return the horizontal position of a joystick hat (d-pad).  Can be
+    ``-1`` (left), ``0`` (centered), or ``1`` (right).  Return ``0`` if
+    the requested joystick or hat does not exist.
 
     Arguments:
 
@@ -104,16 +95,15 @@ def get_hat_x(joystick, hat):
       is the first joystick, or the name of the joystick to check.
     - ``hat`` -- The number of the hat to check, where ``0`` is the
       first hat of the joystick.
-
-    Return ``-1`` (left), ``0`` (centered), or ``1`` (right).  Return
-    ``0`` if the requested joystick or hat does not exist.
-
     """
-    return _get_hat(joystick, hat)[0]
+    return r._get_hat(get_id(joystick), hat)[0]
 
 
 def get_hat_y(joystick, hat):
-    """Return the vertical position of a joystick hat (d-pad).
+    """
+    Return the vertical position of a joystick hat (d-pad).  Can be
+    ``-1`` (up), ``0`` (centered), or ``1`` (down).  Return ``0`` if the
+    requested joystick or hat does not exist.
 
     Arguments:
 
@@ -121,16 +111,14 @@ def get_hat_y(joystick, hat):
       is the first joystick, or the name of the joystick to check.
     - ``hat`` -- The number of the hat to check, where ``0`` is the
       first hat of the joystick.
-
-    Return ``-1`` (up), ``0`` (centered), or ``1`` (down).  Return ``0``
-    if the requested joystick or hat does not exist.
-
     """
-    return -_get_hat(joystick, hat)[1]
+    return -r._get_hat(get_id(joystick), hat)[1]
 
 
 def get_pressed(joystick, button):
-    """Return whether or not a joystick button is pressed.
+    """
+    Return whether or not a joystick button is pressed, or
+    :const:`False` if the requested joystick or button does not exist.
 
     Arguments:
 
@@ -138,138 +126,124 @@ def get_pressed(joystick, button):
       is the first joystick, or the name of the joystick to check.
     - ``button`` -- The number of the button to check, where ``0`` is
       the first button of the joystick.
-
-    ``joystick`` is the number of the joystick to check, where ``0`` is
-    the first joystick.  ``button`` is the number of the button to
-    check, where ``0`` is the first button of the joystick.
-
-    Return :const:`False` if the requested joystick or button does not
-    exist.
-
     """
     joystick = get_id(joystick)
 
-    if (joystick is not None and joystick < len(sge.game._joysticks) and
-            button < sge.game._joysticks[joystick].get_numbuttons()):
-        return sge.game._joysticks[joystick].get_button(button)
+    if (joystick is not None and joystick < len(r.game_joysticks) and
+            button < r.game_joysticks[joystick].get_numbuttons()):
+        return r.game_joysticks[joystick].get_button(button)
     else:
         return False
 
 
 def get_joysticks():
     """Return the number of joysticks available."""
-    return len(sge.game._joysticks)
+    return len(r.game_joysticks)
 
 
 def get_name(joystick):
-    """Return the name of a joystick.
+    """
+    Return the name of a joystick, or :const:`None` if the requested
+    joystick does not exist.
 
     Arguments:
 
     - ``joystick`` -- The number of the joystick to check, where ``0``
       is the first joystick, or the name of the joystick to check.
-
-    Return :const:`None` if the requested joystick does not exist.
-
     """
     if isinstance(joystick, six.integer_types):
-        return sge.game._js_names.setdefault(joystick)
-    elif joystick in sge.game._js_names.values():
+        return r.game_js_names.setdefault(joystick)
+    elif joystick in r.game_js_names.values():
         return joystick
     else:
         return None
 
 
 def get_id(joystick):
-    """Return the number of a joystick, where ``0`` is the first joystick.
+    """
+    Return the number of a joystick, where ``0`` is the first joystick,
+    or :const:`None` if the requested joystick does not exist.
 
     Arguments:
 
     - ``joystick`` -- The number of the joystick to check, where ``0``
       is the first joystick, or the name of the joystick to check.
-
-    Return :const:`None` if the requested joystick does not exist.
-
     """
     if not isinstance(joystick, six.integer_types):
-        return sge.game._js_ids.setdefault(joystick)
-    elif joystick in sge.game._js_names:
+        return r.game_js_ids.setdefault(joystick)
+    elif joystick in r.game_js_names:
         return joystick
     else:
         return None
 
 
 def get_axes(joystick):
-    """Return the number of axes available on a joystick.
+    """
+    Return the number of axes available on a joystick, or ``0`` if the
+    requested joystick does not exist.
 
     Arguments:
 
     - ``joystick`` -- The number of the joystick to check, where ``0``
       is the first joystick, or the name of the joystick to check.
-
-    Return ``0`` if the requested joystick does not exist.
-
     """
     joystick = get_id(joystick)
 
-    if joystick is not None and joystick < len(sge.game._joysticks):
-        return sge.game._joysticks[joystick].get_numaxes()
+    if joystick is not None and joystick < len(r.game_joysticks):
+        return r.game_joysticks[joystick].get_numaxes()
     else:
         return 0
 
 
 def get_hats(joystick):
-    """Return the number of HATs available on a joystick.
+    """
+    Return the number of hats (d-pads) available on a joystick, or ``0``
+    if the requested joystick does not exist.
 
     Arguments:
 
     - ``joystick`` -- The number of the joystick to check, where ``0``
       is the first joystick, or the name of the joystick to check.
-
-    Return ``0`` if the requested joystick does not exist.
-
     """
     joystick = get_id(joystick)
 
-    if joystick is not None and joystick < len(sge.game._joysticks):
-        return sge.game._joysticks[joystick].get_numhats()
+    if joystick is not None and joystick < len(r.game_joysticks):
+        return r.game_joysticks[joystick].get_numhats()
     else:
         return 0
 
 
 def get_trackballs(joystick):
-    """Return the number of trackballs available on a joystick.
+    """
+    Return the number of trackballs available on a joystick, or ``0`` if
+    the requested joystick does not exist.
 
     Arguments:
 
     - ``joystick`` -- The number of the joystick to check, where ``0``
       is the first joystick, or the name of the joystick to check.
-
-    Return ``0`` if the requested joystick does not exist.
-
     """
     joystick = get_id(joystick)
 
-    if joystick is not None and joystick < len(sge.game._joysticks):
-        return sge.game._joysticks[joystick].get_numballs()
+    if joystick is not None and joystick < len(r.game_joysticks):
+        return r.game_joysticks[joystick].get_numballs()
     else:
         return 0
 
 
 def get_buttons(joystick):
-    """Return the number of buttons available on a joystick.
+    """
+    Return the number of buttons available on a joystick, or ``0`` if
+    the requested joystick does not exist.
 
     Arguments:
 
     - ``joystick`` -- The number of the joystick to check, where ``0``
       is the first joystick, or the name of the joystick to check.
-
-    Return ``0`` if the requested joystick does not exist.
-
     """
     joystick = get_id(joystick)
 
-    if joystick is not None and joystick < len(sge.game._joysticks):
-        return sge.game._joysticks[joystick].get_numbuttons()
+    if joystick is not None and joystick < len(r.game_joysticks):
+        return r.game_joysticks[joystick].get_numbuttons()
     else:
         return 0
